@@ -52,10 +52,11 @@ struct _GnomePrintTransport {
 struct _GnomePrintTransportClass {
 	   GObjectClass parent_class;
 	   
-	   gint (* construct) (GnomePrintTransport *transport);
-	   gint (* open)      (GnomePrintTransport *transport);
-	   gint (* close)     (GnomePrintTransport *transport);
-	   gint (* write)     (GnomePrintTransport *transport, const guchar *buf, gint len);
+	   gint (* construct)  (GnomePrintTransport *transport);
+	   gint (* open)       (GnomePrintTransport *transport);
+	   gint (* close)      (GnomePrintTransport *transport);
+	   gint (* write)      (GnomePrintTransport *transport, const guchar *buf, gint len);
+	   gint (* print_file) (GnomePrintTransport *transport, const guchar *file_name);
 };
 
 GType                 gnome_print_transport_get_type (void);
@@ -67,6 +68,10 @@ gint gnome_print_transport_close     (GnomePrintTransport *transport);
 gint gnome_print_transport_write     (GnomePrintTransport *transport, const guchar *buf, gint len);
 gint gnome_print_transport_printf    (GnomePrintTransport *pc, const char *fmt, ...);
 
+#ifdef GNOME_PRINT_UNSTABLE_API
+gint gnome_print_transport_print_file (GnomePrintTransport *transport, const guchar *file_name);
+#endif
+
 G_END_DECLS
 
 #endif /*  __GNOME_PRINT_TRANSPORT_H__ */
