@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  gnome-print-unit.c: Unit utility functio
+ *  gnome-print-unit.c: Unit utility functions
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public License
@@ -17,13 +17,17 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  *  Authors:
+ *    Dirk Luetjens <dirk@luedi.oche.de>
+ *    Yves Arrouye <Yves.Arrouye@marin.fdn.fr>
  *    Lauris Kaplinski <lauris@ximian.com>
  *
- *  Copyright (C) 2001-2202 Ximian, Inc.
- *
+ *  Copyright (C) 1998 The Free Software Foundation and 2001-2202 Ximian, Inc.
  */
 
-#include "config.h"
+#include <config.h>
+
+#define GNOME_PRINT_UNSTABLE_API
+
 #include <libgnomeprint/gnome-print-unit.h>
 #include <libgnomeprint/gnome-print-i18n.h>
 
@@ -42,6 +46,33 @@ static const GnomePrintUnit gp_units[] = {
 
 #define gp_num_units (sizeof (gp_units) / sizeof (gp_units[0]))
 
+static GnomePrintUnit *
+gnome_print_unit_copy (GnomePrintUnit *unit)
+{
+	return unit;
+}
+
+static void
+gnome_print_unit_free (GnomePrintUnit *unit)
+{
+     /* Empty */
+}
+
+GType
+gnome_print_unit_get_type (void)
+{
+	static GType type = 0;
+	
+	if (type == 0) {
+		type = g_boxed_type_register_static
+			("GnomePrintUnit",
+			 (GBoxedCopyFunc) gnome_print_unit_copy,
+			 (GBoxedFreeFunc) gnome_print_unit_free);
+	}
+
+	return type;
+}
+
 /**
  * gnome_print_unit_get_identity:
  * @base: 
@@ -56,24 +87,21 @@ gnome_print_unit_get_identity (guint base)
 	switch (base) {
 	case GNOME_PRINT_UNIT_DIMENSIONLESS:
 		return &gp_units[0];
-		break;
 	case GNOME_PRINT_UNIT_ABSOLUTE:
 		return &gp_units[1];
-		break;
 	case GNOME_PRINT_UNIT_DEVICE:
 		return &gp_units[2];
-		break;
 	case GNOME_PRINT_UNIT_USERSPACE:
 		return &gp_units[3];
-		break;
 	default:
 		g_warning ("file %s: line %d: Illegal unit base %d", __FILE__, __LINE__, base);
-		return FALSE;
-		break;
+		return NULL;
 	}
 }
 
-/* fixme: */
+/* FIXME: return a gettexted default unit so that translators can
+ *        set the default unit on a per locale basis (Chema)
+ */
 const GnomePrintUnit *
 gnome_print_unit_get_default (void)
 {
@@ -149,8 +177,17 @@ gnome_print_unit_free_list (GList *units)
 	g_list_free (units);
 }
 
-/* These are pure utility */
-/* Return TRUE if conversion is possible */
+/**
+ * gnome_print_convert_distance:
+ * @distance: 
+ * @from: 
+ * @to: 
+ * 
+ * Check wether a conversion between @from and @to can be made
+ * 
+ * Return Value: TRUE if the conversion is possible, FALSE if
+ *               it is not or on error
+ **/
 gboolean
 gnome_print_convert_distance (gdouble *distance, const GnomePrintUnit *from, const GnomePrintUnit *to)
 {
@@ -170,6 +207,19 @@ gnome_print_convert_distance (gdouble *distance, const GnomePrintUnit *from, con
 }
 
 /* ctm is for userspace, devicetransform is for device units */
+
+/**
+ * gnome_print_convert_distance_full:
+ * @distance: 
+ * @from: 
+ * @to: 
+ * @ctmscale: 
+ * @devicescale: 
+ * 
+ * ctmscale is userspace->absolute, devicescale is device->absolute
+ * 
+ * Return Value: 
+ **/
 gboolean
 gnome_print_convert_distance_full (gdouble *distance, const GnomePrintUnit *from, const GnomePrintUnit *to,
 				   gdouble ctmscale, gdouble devicescale)
@@ -180,7 +230,8 @@ gnome_print_convert_distance_full (gdouble *distance, const GnomePrintUnit *from
 	g_return_val_if_fail (from != NULL, FALSE);
 	g_return_val_if_fail (to != NULL, FALSE);
 
-	if (from->base == to->base) return gnome_print_convert_distance (distance, from, to);
+	if (from->base == to->base)
+		return gnome_print_convert_distance (distance, from, to);
 
 	if ((from->base == GNOME_PRINT_UNIT_DIMENSIONLESS) || (to->base == GNOME_PRINT_UNIT_DIMENSIONLESS)) {
 		*distance = *distance * from->unittobase / to->unittobase;
@@ -238,3 +289,23 @@ gnome_print_convert_distance_full (gdouble *distance, const GnomePrintUnit *from
 	return TRUE;
 }
 
+/**
+ * gnome_print_unit_get_name:
+ * @unit: The unit that we want to get the name from
+ * @plural: flag to specify single or plural name [Inch v.s. Inches]
+ * @abbreviation: flag to specify abbreviation or full name [Inch v.s. in]
+ * @flags: 0 for now, used for future expansion
+ *
+ * Returns the translated user visible name for @unit
+ *
+ * Return Value: a translated malloced string on success, NULL otherwise
+ **/
+gchar *
+gnome_print_unit_get_name (const GnomePrintUnit *unit, gboolean plural, gboolean abbreviation, gint flags)
+{
+	gchar *name;
+
+	name = g_strdup (_((abbreviation) ? (plural) ? unit->abbr_plural : unit->abbr : (plural) ? unit->plural : unit->name));
+
+	return name;
+}
